==> seeuletter-1.1.0-py3-none-any.whl: seeuletter/resource.py <==
from __future__ import unicode_literals

import json

from seeuletter import api_requestor
from seeuletter.compat import string_type


def seeuletter_format(resp):
    types = {
        'letter': Letter,
        'postcard': Postcard
    }

    # Change Keys for To/From
    if isinstance(resp, dict) and 'to' in resp:
        resp['to_address'] = resp['to']
        resp.pop('to', None)
    if isinstance(resp, dict) and 'from' in resp:
        resp['from_address'] = resp['from']
        resp.pop('from', None)
        
    # Recursively Set Objects for Lists
    if isinstance(resp, dict) and 'object' in resp and resp['object'] == 'list':
        resp['data'] = [seeuletter_format(i) for i in resp['data']]
        return SeeuletterObject.construct_from(resp)
    if isinstance(resp, dict) and not isinstance(resp, SeeuletterObject):
        resp = resp.copy()
        if 'object' in resp and isinstance(resp['object'], string_type):
            klass = types.get(resp['object'], SeeuletterObject)
        else:
            klass = SeeuletterObject

        # Check For Arrays
        for key in resp:
            if isinstance(resp[key], list):
                resp[key] = [seeuletter_format(i) for i in resp[key]]
        return klass.construct_from(resp)
    else:
        return resp


class SeeuletterObject(dict):

    def __init__(self, id=None, **params):
        super(SeeuletterObject, self).__init__()
        if id:
            self['id'] = id

    @classmethod
    def construct_from(cls, values):
        instance = cls(values.get('id'))
        for k, v in values.items():
            instance[k] = seeuletter_format(v)
        return instance

    def __getattr__(self, k):
        try:
            return self[k]
        except KeyError:
            raise AttributeError(k)  

    def __setattr__(self, k, v):
        self[k] = v

    def __repr__(self):
        ident_parts = [type(self).__name__]

        if isinstance(self.get('object'), string_type):
            ident_parts.append(self.get('object'))

        if isinstance(self.get('id'), string_type):
            ident_parts.append('id=%s' % (self.get('id'),))

        unicode_repr = '<%s at %s> JSON: %s' % (
            ' '.join(ident_parts), hex(id(self)), str(self))

        return unicode_repr

    def __str__(self):
        return json.dumps(self, sort_keys=True, indent=2)


class APIResource(SeeuletterObject):
    @classmethod
    def retrieve(cls, id, **params):
        requestor = api_requestor.APIRequestor()
        response = requestor.request('get', '%s/%s' % (cls.endpoint, id), params)
        return seeuletter_format(response)

# API Operations
class ListableAPIResource(APIResource):
    @classmethod
    def list(cls, **params):
        for key, value in params.copy().items():
            if isinstance(params[key], dict):
                for subKey in value:
                    params[str(key) + '[' + subKey + ']'] = value[subKey]
                del params[key]
            elif isinstance(params[key], list):
                params[str(key) + '[]'] = params[key]
                del params[key]
        requestor = api_requestor.APIRequestor()
        response = requestor.request('get', cls.endpoint, params)
        return seeuletter_format(response)


class CreateableAPIResource(APIResource):
    @classmethod
    def create(cls, **params):
        requestor = api_requestor.APIRequestor()
        if 'channel' in params.keys():
            response = requestor.request('post', '{0}{1}'.format(cls.endpoint, params['channel']), params)
        else:
            response = requestor.request('post', cls.endpoint, params)
        return seeuletter_format(response)

class Letter(ListableAPIResource, CreateableAPIResource):
    endpoint = '/letters'
    
    @classmethod
    def create(cls, **params):
        if isinstance(params, dict):
            if 'from_address' in params:
                params['from'] = params['from_address']
                params.pop('from_address')
            if 'to_address' in params:
                params['to'] = params['to_address']
                params.pop('to_address')
        return super(Letter, cls).create(**params)
	
    @classmethod
    def createElectronic(cls, **params):
        params['channel'] = '/electronic'
        if isinstance(params, dict):
            if 'from_address' in params:
                params['from'] = params['from_address']
                params.pop('from_address')
            if 'to_address' in params:
                params['to'] = params['to_address']
                params.pop('to_address')
        return super(Letter, cls).create(**params)

class Postcard(ListableAPIResource, CreateableAPIResource):
    endpoint = '/postcards'
    @classmethod
    def create(cls, **params):
        if isinstance(params, dict):
            if 'from_address' in params:
                params['from'] = params['from_address']
                params.pop('from_address')
            if 'to_address' in params:
                params['to'] = params['to_address']
                params.pop('to_address')
        return super(Postcard, cls).create(**params)

==> seeuletter-1.2.0-py3-none-any.whl: seeuletter/resource.py <==
from __future__ import unicode_literals

import json

from seeuletter import api_requestor
from seeuletter.compat import string_type


def seeuletter_format(resp):
    types = {
        'letter': Letter,
        'postcard': Postcard,
        'account': Account,
        'invoice': Invoice
    }

    # Change Keys for To/From
    if isinstance(resp, dict) and 'to' in resp:
        resp['to_address'] = resp['to']
        resp.pop('to', None)
    if isinstance(resp, dict) and 'from' in resp:
        resp['from_address'] = resp['from']
        resp.pop('from', None)
        
    # Recursively Set Objects for Lists
    if isinstance(resp, dict) and 'object' in resp and resp['object'] == 'list':
        resp['data'] = [seeuletter_format(i) for i in resp['data']]
        return SeeuletterObject.construct_from(resp)
    if isinstance(resp, dict) and not isinstance(resp, SeeuletterObject):
        resp = resp.copy()
        if 'object' in resp and isinstance(resp['object'], string_type):
            klass = types.get(resp['object'], SeeuletterObject)
        else:
            klass = SeeuletterObject

        # Check For Arrays
        for key in resp:
            if isinstance(resp[key], list):
                resp[key] = [seeuletter_format(i) for i in resp[key]]
        return klass.construct_from(resp)
    else:
        return resp


class SeeuletterObject(dict):

    def __init__(self, id=None, **params):
        super(SeeuletterObject, self).__init__()
        if id:
            self['id'] = id

    @classmethod
    def construct_from(cls, values):
        instance = cls(values.get('id'))
        for k, v in values.items():
            instance[k] = seeuletter_format(v)
        return instance

    def __getattr__(self, k):
        try:
            return self[k]
        except KeyError:
            raise AttributeError(k)  

    def __setattr__(self, k, v):
        self[k] = v

    def __repr__(self):
        ident_parts = [type(self).__name__]

        if isinstance(self.get('object'), string_type):
            ident_parts.append(self.get('object'))

        if isinstance(self.get('id'), string_type):
            ident_parts.append('id=%s' % (self.get('id'),))

        unicode_repr = '<%s at %s> JSON: %s' % (
            ' '.join(ident_parts), hex(id(self)), str(self))

        return unicode_repr

    def __str__(self):
        return json.dumps(self, sort_keys=True, indent=2)


class APIResource(SeeuletterObject):
    @classmethod
    def retrieve(cls, id, **params):
        requestor = api_requestor.APIRequestor()
        response = requestor.request('get', '%s/%s' % (cls.endpoint, id), params)
        return seeuletter_format(response)

# API Operations
class ListableAPIResource(APIResource):
    @classmethod
    def list(cls, **params):
        for key, value in params.copy().items():
            if isinstance(params[key], dict):
                for subKey in value:
                    params[str(key) + '[' + subKey + ']'] = value[subKey]
                del params[key]
            elif isinstance(params[key], list):
                params[str(key) + '[]'] = params[key]
                del params[key]
        requestor = api_requestor.APIRequestor()
        response = requestor.request('get', cls.endpoint, params)
        return seeuletter_format(response)


class CreateableAPIResource(APIResource):
    @classmethod
    def create(cls, **params):
        requestor = api_requestor.APIRequestor()
        if 'channel' in params.keys():
            response = requestor.request('post', '{0}{1}'.format(cls.endpoint, params['channel']), params)
        else:
            response = requestor.request('post', cls.endpoint, params)
        return seeuletter_format(response)

class UpdatableAPIResource(APIResource):
    @classmethod
    def update(cls, id, **params):
        requestor = api_requestor.APIRequestor()
        response = requestor.request('put', '%s/%s' % (cls.endpoint, id), params)

        return seeuletter_format(response)

class Letter(ListableAPIResource, CreateableAPIResource):
    endpoint = '/letters'
    
    @classmethod
    def create(cls, **params):
        if isinstance(params, dict):
            if 'from_address' in params:
                params['from'] = params['from_address']
                params.pop('from_address')
            if 'to_address' in params:
                params['to'] = params['to_address']
                params.pop('to_address')
        return super(Letter, cls).create(**params)
	
    @classmethod
    def createElectronic(cls, **params):
        params['channel'] = '/electronic'
        if isinstance(params, dict):
            if 'from_address' in params:
                params['from'] = params['from_address']
                params.pop('from_address')
            if 'to_address' in params:
                params['to'] = params['to_address']
                params.pop('to_address')
        return super(Letter, cls).create(**params)

class Postcard(ListableAPIResource, CreateableAPIResource):
    endpoint = '/postcards'

    @classmethod
    def create(cls, **params):
        if isinstance(params, dict):
            if 'from_address' in params:
                params['from'] = params['from_address']
                params.pop('from_address')
            if 'to_address' in params:
                params['to'] = params['to_address']
                params.pop('to_address')
        return super(Postcard, cls).create(**params)

class Account(CreateableAPIResource, UpdatableAPIResource):
    endpoint = '/accounts'

    @classmethod
    def create(cls, **params):
        return super(Account, cls).create(**params)

    @classmethod
    def updateEmail(cls, id, email):
        params = {
            'email': email
        }
        return super(Account, cls).update(id, **params)

class Invoice(ListableAPIResource):
    endpoint = '/invoices'
